#!/usr/bin/bash

#arguments
single_record_fasta=$1
multi_record_fasta=$2
readLength=$3
entrypoint=$4
outdir=$5
windowSize=100
fasta_name=$(echo $single_record_fasta | perl -p -e 's/.*\/(.*)\.(fa|fasta)$/$1/')

# create dir to store results
mkdir -p $outdir/copyCat_annotation/readlength.$readLength/gcWinds
mkdir -p $outdir/copyCat_annotation/readlength.$readLength/mapability

#generate all possible reads of the given size from that chromsome
perl allSeq.pl $single_record_fasta $readLength > $outdir/copyCat_annotation/$fasta_name.fastq

# align those reads using bwa
bwa aln -t 4 $multi_record_fasta $outdir/copyCat_annotation/$fasta_name.fastq >$outdir/copyCat_annotation/$fasta_name.aln.sai
bwa samse -n 1 $multi_record_fasta $outdir/copyCat_annotation/$fasta_name.aln.sai $outdir/copyCat_annotation/$fasta_name.fastq >$outdir/copyCat_annotation/$fasta_name.sam

#clean up
rm -f $outdir/copyCat_annotation/$fasta_name.fastq $outdir/copyCat_annotation/$fasta_name.aln.sai

#convert the sam file to a mapability and gc-content tracks 
perl mapAndGc.pl $outdir/copyCat_annotation/$fasta_name.sam $entrypoint $windowSize $fasta_name $readLength $outdir/copyCat_annotation

# compress and cleanup
gzip $outdir/copyCat_annotation/readlength.$readLength/gcWinds/$fasta_name.gc
gzip $outdir/copyCat_annotation/readlength.$readLength/mapability/$fasta_name.dat
rm -f $outdir/copyCat_annotation/$fasta_name.sam

# copy the entrypoints file if they don't already exist
cp -n $entrypoint $outdir/copyCat_annotation/
